@@ -6,6 +6,7 @@ from remotecv.detectors.feature_detector import FeatureDetector
 from remotecv.detectors.glasses_detector import GlassesDetector
 from remotecv.detectors.profile_detector import ProfileDetector
 from remotecv.detectors.complete_detector import CompleteDetector
+from remotecv.image import Image
 
 class ImageProcessor:
     def __init__(self):
@@ -17,8 +18,11 @@ class ImageProcessor:
             'prof': ProfileDetector()
         }
 
-    def detect(self, detector, size, mode, img_data):
+    def detect(self, detector, image_data):
         detector = self.detectors[detector]
         if detector is None:
             return None
-        return detector.detect(size[0], size[1], mode, img_data)
+
+        image = Image.create_from_buffer(image_data)
+        image.grayscale()
+        return detector.detect(image)
